@@ -1,7 +1,4 @@
-"""Class Exception."""
-import logging
-
-_LOGGER = logging.getLogger(__name__)
+"""Class exception."""
 
 
 class EnedisException(Exception):
