@@ -34,14 +34,9 @@ class EnedisAnalytics:
         freq: str = "H",
         summary: bool = False,
         cumsums: dict[str, Any] = {},
-        prices: Tuple[float, float] | None = None,
+        prices: list[dict[str, Any]] | None = None,
     ) -> Any:
         """Convert datas to analyze."""
-        std_cum_sum = cumsums.get("standard", {}).get("sum_value", 0)
-        std_cum_sum_price = cumsums.get("standard", {}).get("sum_price", 0)
-        off_cum_sum = cumsums.get("offpeak", {}).get("sum_value", 0)
-        off_cum_sum_price = cumsums.get("offpeak", {}).get("sum_price", 0)
-
         if not self.df.empty:
             # Convert str to datetime
             self.df.date = pd.to_datetime(self.df.date, format="%Y-%m-%d %H:%M:%S")
@@ -94,27 +89,33 @@ class EnedisAnalytics:
             )
 
         if prices:
-            self.df.loc[(self.df.notes == "standard"), "price"] = (
-                self.df.value * prices[0]
-            )
-            self.df.loc[(self.df.notes == "offpeak"), "price"] = (
-                self.df.value * prices[1]
-            )
+            for price in prices:
+                for mode, item in price.items():
+                    if s_date := item.get("date"):
+                        self.df.loc[
+                            (self.df.notes == mode)
+                            & (
+                                self.df.date.dt.date
+                                == pd.to_datetime(s_date, format="%Y-%m-%d").date()
+                            ),
+                            "price",
+                        ] = self.df.value * item.get("price", 0)
+                    else:
+                        self.df.loc[
+                            (self.df.notes == mode), "price"
+                        ] = self.df.value * item.get("price", 0)
 
-        if summary and prices:
-            self.df.loc[(self.df.notes == "standard"), "sum_value"] = (
-                self.df[(self.df.notes == "standard")].value.cumsum() + std_cum_sum
-            )
-            self.df.loc[(self.df.notes == "offpeak"), "sum_value"] = (
-                self.df[(self.df.notes == "offpeak")].value.cumsum() + off_cum_sum
-            )
-            self.df.loc[(self.df.notes == "standard"), "sum_price"] = (
-                self.df[(self.df.notes == "standard")].price.cumsum()
-                + std_cum_sum_price
-            )
-            self.df.loc[(self.df.notes == "offpeak"), "sum_price"] = (
-                self.df[(self.df.notes == "offpeak")].price.cumsum() + off_cum_sum_price
-            )
+            if summary:
+                for mode, sums in cumsums.items():
+                    self.df.loc[(self.df.notes == mode), "sum_price"] = self.df[
+                        (self.df.notes == mode)
+                    ].price.cumsum() + sums.get("sum_price")
+
+        if summary:
+            for mode, sums in cumsums.items():
+                self.df.loc[(self.df.notes == mode), "sum_value"] = self.df[
+                    (self.df.notes == mode)
+                ].value.cumsum() + sums.get("sum_value")
 
         return self.df.to_dict(orient="records")
 
