@@ -20,6 +20,7 @@ async def test_hours_analytics() -> None:
         "standard": {"sum_value": 1000, "sum_price": 0},
         "offpeak": {"sum_value": 1000, "sum_price": 0},
     }
+    prices = [{"standard": {"price": 0.17}, "offpeak": {"price": 0.18}}]
     intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
     analytics = EnedisAnalytics(dataset)
     resultat = analytics.get_data_analytics(
@@ -30,7 +31,7 @@ async def test_hours_analytics() -> None:
         groupby=True,
         summary=True,
         cumsums=cumsums,
-        prices=(0.17, 0.18),
+        prices=prices,
     )
     assert resultat[0]["notes"] == "offpeak"
     assert resultat[0]["value"] == 0.618
@@ -45,7 +46,7 @@ async def test_hours_analytics() -> None:
         intervals=intervals,
         freq="H",
         groupby=True,
-        prices=(0.17, 0.18),
+        prices=prices,
     )
     assert resultat[0]["notes"] == "offpeak"
     assert resultat[0]["value"] == 0.618
@@ -60,7 +61,7 @@ async def test_hours_analytics() -> None:
         intervals=intervals,
         freq="H",
         groupby=True,
-        prices=(0.17, 0.18),
+        prices=prices,
     )
     print(resultat)
 
@@ -85,7 +86,7 @@ async def test_hours_analytics() -> None:
         groupby=True,
         summary=True,
         cumsums=cumsums,
-        prices=(0.17, 0.18),
+        prices=prices,
     )
     assert resultat[0]["value"] == 33.951
     assert resultat[3]["value"] == 43.608
@@ -94,6 +95,7 @@ async def test_hours_analytics() -> None:
 
 @pytest.mark.asyncio
 async def test_daily_analytics() -> None:
+    prices = [{"standard": {"price": 0.17}, "offpeak": {"price": 0.18}}]
     dataset = DS_30["meter_reading"]["interval_reading"]
     intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
     dataset = DS_DAILY["meter_reading"]["interval_reading"]
@@ -105,7 +107,7 @@ async def test_daily_analytics() -> None:
         freq="D",
         groupby=True,
         summary=True,
-        prices=(0.17, 0.18),
+        prices=prices,
     )
     assert resultat[359]["value"] == 68.68
     print(resultat)
@@ -113,6 +115,7 @@ async def test_daily_analytics() -> None:
 
 @pytest.mark.asyncio
 async def test_compare_analytics() -> None:
+    prices = [{"standard": {"price": 0.17}, "offpeak": {"price": 0.18}}]
     cumsums = {
         "standard": {"sum_value": 0, "sum_price": 0},
         "offpeak": {"sum_value": 0, "sum_price": 0},
@@ -128,7 +131,7 @@ async def test_compare_analytics() -> None:
         groupby=True,
         summary=True,
         cumsums=cumsums,
-        prices=(0.17, 0.18),
+        prices=prices,
         start_date="2023-02-28",
     )
     print(resultat1)
@@ -148,7 +151,7 @@ async def test_compare_analytics() -> None:
         groupby=True,
         summary=True,
         cumsums=cumsums,
-        prices=(0.17, 0.18),
+        prices=prices,
         start_date="2023-02-28",
     )
     assert sum_value == resultat2[2]["sum_value"]
@@ -157,6 +160,7 @@ async def test_compare_analytics() -> None:
 
 @pytest.mark.asyncio
 async def test_cumsums_analytics() -> None:
+    prices = [{"standard": {"price": 0.17}, "offpeak": {"price": 0.18}}]
     cumsums = {
         "standard": {"sum_value": 100, "sum_price": 50},
         "offpeak": {"sum_value": 1000, "sum_price": 75},
@@ -172,7 +176,7 @@ async def test_cumsums_analytics() -> None:
         groupby=True,
         summary=True,
         cumsums=cumsums,
-        prices=(0.17, 0.18),
+        prices=prices,
         start_date="2023-02-28",
     )
     # offpeak
@@ -181,3 +185,40 @@ async def test_cumsums_analytics() -> None:
     # standard
     assert resultat[3]["sum_value"] == resultat[3]["value"] + 100
     assert resultat[3]["sum_price"] == resultat[3]["price"] + 50
+
+
+@pytest.mark.asyncio
+async def test_tempo_analytics() -> None:
+    prices = [
+        {
+            "standard": {"price": 0.2, "date": "2023-03-01"},
+            "offpeak": {"price": 0.3, "date": "2023-03-01"},
+        },
+        {
+            "standard": {"price": 0.1, "date": "2023-03-02"},
+            "offpeak": {"price": 0.2, "date": "2023-03-02"},
+        },
+        {
+            "standard": {"price": 0.2, "date": "2023-03-03"},
+            "offpeak": {"price": 0.3, "date": "2023-03-03"},
+        },
+    ]
+    cumsums = {
+        "standard": {"sum_value": 100, "sum_price": 50},
+        "offpeak": {"sum_value": 1000, "sum_price": 75},
+    }
+    intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
+    dataset = DS_30["meter_reading"]["interval_reading"]
+    analytics = EnedisAnalytics(dataset)
+    resultat = analytics.get_data_analytics(
+        convertKwh=True,
+        convertUTC=False,
+        intervals=intervals,
+        freq="D",
+        groupby=True,
+        summary=True,
+        cumsums=cumsums,
+        prices=prices,
+        start_date="2023-02-28",
+    )
+    print(resultat)
